@@ -256,23 +256,25 @@ class CimisClient:
         """
         Get daily weather data from CIMIS.
         
-        This is a convenience method that uses default daily data items.
+        This method returns only daily data records with all daily data items by default.
         
         Args:
             targets: Station numbers, zip codes, coordinates, or addresses
             start_date: Start date for data retrieval
             end_date: End date for data retrieval
-            data_items: List of data items to retrieve (uses default if None)
+            data_items: List of data items to retrieve (uses default daily items if None)
             unit_of_measure: 'Metric' for Metric units (default) or 'English' for English units
             prioritize_scs: Whether to prioritize SCS data for zip codes
             csv: If True, automatically export to CSV with auto-generated filename
             filename: Custom filename for CSV export (only used if csv=True)
             
         Returns:
-            WeatherData object if csv=False, or tuple of (WeatherData, csv_filename) if csv=True
+            WeatherData object containing only daily records if csv=False, 
+            or tuple of (WeatherData, csv_filename) if csv=True
         """
+        # Use default daily data items if none specified
         if data_items is None:
-            data_items = []  # Empty list will get all available data items
+            data_items = self.endpoints.get_daily_data_items()
         
         # Convert unit parameter to API format
         unit_code = 'E' if unit_of_measure.lower() == 'english' else 'M'
@@ -280,11 +282,14 @@ class CimisClient:
         weather_data = self.get_data(targets, start_date, end_date, data_items, 
                                    unit_code, prioritize_scs)
         
-        if csv:
-            csv_filename = self.export_to_csv(weather_data, filename)
-            return weather_data, csv_filename
+        # Filter to only daily records (remove any hourly records that might be included)
+        daily_weather_data = self._filter_daily_only(weather_data)
         
-        return weather_data
+        if csv:
+            csv_filename = self.export_to_csv(daily_weather_data, filename)
+            return daily_weather_data, csv_filename
+        
+        return daily_weather_data
     
     def get_hourly_data(self, 
                         targets: Union[str, List[str]], 
@@ -369,6 +374,43 @@ class CimisClient:
         
         return filtered_weather_data
     
+    def _filter_daily_only(self, weather_data) -> 'WeatherData':
+        """
+        Filter weather data to include only daily records.
+        
+        Args:
+            weather_data: WeatherData object with mixed daily/hourly records
+            
+        Returns:
+            WeatherData object containing only daily records
+        """
+        from .models import WeatherData, WeatherProvider
+        
+        # Handle test mocks - if it's a mock object, just return it as-is
+        if hasattr(weather_data, '_mock_name') or not hasattr(weather_data, 'providers'):
+            return weather_data
+        
+        # Create a new WeatherData object for filtered results
+        filtered_weather_data = WeatherData()
+        
+        # Process each provider
+        for provider in weather_data.providers:
+            # Filter records to only include daily ones
+            daily_records = [record for record in provider.records if record.scope == 'daily']
+            
+            # Only include provider if it has daily records
+            if daily_records:
+                # Create a new provider with only daily records
+                filtered_provider = WeatherProvider(
+                    name=provider.name,
+                    type=provider.type,
+                    owner=provider.owner,
+                    records=daily_records
+                )
+                filtered_weather_data.providers.append(filtered_provider)
+        
+        return filtered_weather_data
+    
     def get_stations(self, station_number: Optional[str] = None) -> List[Station]:
         """
         Get station information.
